@@ -47,11 +47,12 @@ slvxa_histo_timescale:\
     slvxa_histo_timescale_head\
     int_multiline_array15
 
+// SLVX2960
 slvxa_histo_timescale_head:\
     ELEM _S TTLS_TNAME _NL\
     "Histogram scale (fs)" _S pfloat _S\
-    "Origin in channel" _S pint _S\
-    "First reported channel" _S pint _S\
+    "Origin in channel" fwint5 _S\
+    "First reported channel" fwint5 _S\
     "Entries" _S pint _NL
 
 slvxa_histo_moving_particle:\
@@ -67,6 +68,7 @@ slvxa_histo_inv_energy:\
     slvxa_histo_inv_energy_head\
     int_multiline_array15
 
+// SLAVX5300
 slvxa_histo_inv_energy_head:\
     ELEM _S TTLS_ENAME _NL\
     "Inverse channel width (eV)" _S pfloat _S\
@@ -77,10 +79,11 @@ slvxa_histo_sputtered_energy:\
     slvxa_histo_sputtered_energy_head\
     int_multiline_array15
 
+// SLVX6240
 slvxa_histo_sputtered_energy_head:\
     ELEM _S TTLS_ZNAME _NL\
     "Channel width" _S pfloat _S\
-    "Origin in channel" _S pint _S\
+    "Origin in channel" fwint5 _S\
     "First reported channel" _S pint _S\
     "Total entries" _S pint _NL
 
@@ -88,6 +91,7 @@ slvxa_histo_final_energy:\
     slvxa_histo_final_energy_head\
     int_multiline_array10
 
+// SLVX5530
 slvxa_histo_final_energy_head:\
     ELEM _S TTLS_FNAME _NL\
     "Channel width (eV)" _S pfloat _S\
@@ -97,11 +101,12 @@ slvxa_histo_binding_energy:\
     slvxa_histo_binding_energy_head\
     int_multiline_array10
 
+// SLVX6290
 slvxa_histo_binding_energy_head:\
     ELEM _S TTLS_QNAME _NL\
     "Channel width (eV)" _S pfloat _S\
-    "Origin in channel" _S pint _S\
-    "First reported channel" _S pint _S\
+    "Origin in channel" fwint5 _S\
+    "First reported channel" fwint5 _S\
     "Entries" _S pint _NL
 '''
 
@@ -109,6 +114,7 @@ grammer_join_list = [grammar,
         grammar_stat,
         grammar_histo,
         lark_common.grammar,
+        lark_common.grammar_fixedwidth_int,
         lark_common.grammar_elem,
         lark_common.grammar_ttls_momx,
         lark_common.grammar_ttls_hname,
@@ -127,7 +133,7 @@ class Context():
     def __init__(self):
         self.mobj = []
 
-class Transformer(lark.Transformer):
+class Transformer(lark_common.Transformer):
     def __init__(self, context):
         super().__init__()
         self.context = context
